#!/bin/bash

status=0

# If not run from automake, fake it
if [ -z "$srcdir" ]; then
    srcdir="$(dirname "$0")"
fi

if [ 1 = 1 ]; then
    python3 ${srcdir}/libbytesize_unittest.py || status=1
    python3 ${srcdir}/lbs_py_override_unittest.py || status=1
fi

if [ 1 = 1 ]; then
    python3 ${srcdir}/libbytesize_unittest.py fr_FR.UTF-8 || status=1
fi

exit $status
